@@ -77,7 +77,7 @@ class HotEmissionsModel:
         :param powertrain_type: "diesel", "petrol" or "CNG"
         :type powertrain_type: str
         :param euro_class: integer, corresponding to the EURO pollution class
-        :type euro_class: int
+        :type euro_class: float
         :return: Pollutants emission per km driven, per air compartment.
         :rtype: numpy.array
         """
@@ -97,7 +97,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.194e-06 * c ** 3 - 0.0002084 * c ** 2 + 0.01159 * c + 0.459) + (9.552e-08 * c ** 3 - 1.668e-05 * c ** 2 + 0.0009269 * c + 0.03672)"
+                    "(1.194e-06 * c ** 3 - 0.0002084 * c ** 2 + 0.01159 * c + 0.459)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate("-5.921e-08 * c ** 3 + 6.236e-05 * c ** 2 - 0.007949 * c + 0.3523")
@@ -134,7 +134,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.212e-06 * c ** 3 - 0.0001786 * c ** 2 + 0.007101 * c + 0.4974) + (9.693e-08 * c ** 3 - 1.429e-05 * c ** 2 + 0.0005681 * c + 0.0398)"
+                    "(1.212e-06 * c ** 3 - 0.0001786 * c ** 2 + 0.007101 * c + 0.4974) "
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate("-6.042e-08 * c ** 3 + 3.566e-05 * c ** 2 - 0.004057 * c + 0.2134")
@@ -171,7 +171,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.293e-06 * c ** 3 - 0.0001745 * c ** 2 + 0.00481 * c + 0.6594) + (1.422e-07 * c ** 3 - 1.92e-05 * c ** 2 + 0.0005291 * c + 0.07254)"
+                    "(1.293e-06 * c ** 3 - 0.0001745 * c ** 2 + 0.00481 * c + 0.6594)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate("-1.135e-07 * c ** 3 + 3.772e-05 * c ** 2 - 0.003626 * c + 0.1598")
@@ -208,7 +208,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(2.692e-06 * c ** 3 - 0.0004576 * c ** 2 + 0.02411 * c + 0.3662) + (9.421e-07 * c ** 3 - 0.0001602 * c ** 2 + 0.00844 * c + 0.1282)"
+                    "(2.692e-06 * c ** 3 - 0.0004576 * c ** 2 + 0.02411 * c + 0.3662)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate("3.662e-08 * c ** 3 - 3.196e-06 * c ** 2 - 0.0001999 * c + 0.04362")
@@ -245,7 +245,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.938e-06 * c ** 3 - 0.0002904 * c ** 2 + 0.01012 * c + 0.6372) + (8.348e-07 * c ** 3 - 0.0001251 * c ** 2 + 0.004358 * c + 0.2744)"
+                    "(1.938e-06 * c ** 3 - 0.0002904 * c ** 2 + 0.01012 * c + 0.6372)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate("-1.386e-08 * c ** 3 + 5.912e-06 * c ** 2 - 0.0006624 * c + 0.03824")
@@ -282,7 +282,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.634e-06 * c ** 3 - 0.0002633 * c ** 2 + 0.01063 * c + 0.5499) + (5.312e-07 * c ** 3 - 8.517e-05 * c ** 2 + 0.003398 * c + 0.1846)"
+                    "(1.634e-06 * c ** 3 - 0.0002633 * c ** 2 + 0.01063 * c + 0.5499) "
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate("-3.416e-09 * c ** 3 + 1.005e-06 * c ** 2 - 0.0001049 * c + 0.005359")
@@ -308,7 +308,138 @@ class HotEmissionsModel:
                 em_arr[:, 10] = ne.evaluate(
                     "-8.782e-11 * c ** 3 + 3.059e-08 * c ** 2 - 3.761e-06 * c + 0.0001954"
                 )
-            if euro_class == 6:
+
+            if euro_class == 6.0:
+                # EURO 6-ab
+                #HC
+                em_arr[:, 0] = ne.evaluate(
+                "3.156e-08 * c ** 3 - 6.092e-06 * c ** 2 + 0.0002999 * c + 0.0125"
+                )
+                #CO
+                em_arr[:, 1] = ne.evaluate(
+                "8.375e-08 * c ** 3 - 1.282e-05 * c ** 2 - 0.0001148 * c + 0.1052"
+                )
+                #NOx + NO2
+                em_arr[:, 2] = ne.evaluate(
+                    "(1.183e-06 * c ** 3 - 0.0002066 * c ** 2 + 0.01106 * c + 0.2807)"
+                    )
+                #PM
+                em_arr[:, 3] = ne.evaluate(
+                "-2.807e-10 * c ** 3 + 2.184e-07 * c ** 2 - 2.521e-05 * c + 0.00126"
+                )
+
+                #CH4
+                em_arr[:, 4] = ne.evaluate(
+               "2.84e-08 * c ** 3 - 5.482e-06 * c ** 2 + 0.0002699 * c + 0.01125"
+                )
+                #NMHC
+                em_arr[:, 5] = ne.evaluate(
+                "3.156e-09 * c ** 3 - 6.092e-07 * c ** 2 + 2.999e-05 * c + 0.00125"
+                )
+                #Pb
+                # No Pb!
+
+                #SO2
+                em_arr[:, 7] = ne.evaluate(
+                "3.993e-10 * c ** 3 - 7.997e-09 * c ** 2 - 5.447e-06 * c + 0.001213"
+                )
+                #N2O
+                em_arr[:, 8] = 0.01
+                #NH3
+                em_arr[:, 9] = 0.006
+                #Benzene
+                em_arr[:, 10] = ne.evaluate(
+                    "2.525e-10 * c ** 3 - 4.873e-08 * c ** 2 + 2.399e-06 * c + 0.0001"
+                )
+
+            if euro_class == 6.1:
+                # EURO 6-c
+                #HC
+                em_arr[:, 0] = ne.evaluate(
+                "9.641e-09 * c ** 3 - 1.899e-06 * c ** 2 + 0.000122 * c + 0.008276"
+                )
+                #CO
+                em_arr[:, 1] = ne.evaluate(
+                "3.007e-08 * c ** 3 - 3.641e-06 * c ** 2 - 0.0002374 * c + 0.05297"
+                )
+                #NOx + NO2
+                em_arr[:, 2] = ne.evaluate(
+                    "(5.086e-07 * c ** 3 - 8.662e-05 * c ** 2 + 0.004389 * c + 0.1175)"
+                    )
+                #PM
+                em_arr[:, 3] = ne.evaluate(
+                "1.302e-09 * c ** 3 - 2.298e-07 * c ** 2 + 1.141e-05 * c + 0.0003679"
+                )
+
+                #CH4
+                em_arr[:, 4] = ne.evaluate(
+                "8.677e-09 * c ** 3 - 1.709e-06 * c ** 2 + 0.0001098 * c + 0.007448"
+                )
+                #NMHC
+                em_arr[:, 5] = ne.evaluate(
+                "9.641e-10 * c ** 3 - 1.899e-07 * c ** 2 + 1.22e-05 * c + 0.0008276"
+                )
+                #Pb
+                # No Pb!
+
+                #SO2
+                em_arr[:, 7] = ne.evaluate(
+                "3.612e-10 * c ** 3 - 5.179e-09 * c ** 2 - 5.282e-06 * c + 0.001133"
+                )
+                #N2O
+                em_arr[:, 8] = 0.01
+                #NH3
+                em_arr[:, 9] = 0.006
+                #Benzene
+                em_arr[:, 10] = ne.evaluate(
+                    "7.713e-11 * c ** 3 - 1.519e-08 * c ** 2 + 9.757e-07 * c + 6.621e-05"
+                )
+
+            if euro_class == 6.2:
+                # EURO 6-d-temp
+                #HC
+                em_arr[:, 0] = ne.evaluate(
+                "1.876e-10 * c **3 - 1.283e-07 * c ** 2 + 5.19e-05 * c + 0.005754"
+                )
+                #CO
+                em_arr[:, 1] = ne.evaluate(
+                "3.432e-09 * c **3 + 9.136e-07 * c ** 2  - 0.0002983 * c + 0.02698"
+                )
+                #NOx + NO2
+                em_arr[:, 2] = ne.evaluate(
+                    "(1.335e-07 * c **3 - 2.156e-05 * c ** 2  + 0.0009388 * c + 0.02214)"
+                    )
+                #PM
+                em_arr[:, 3] = ne.evaluate(
+                "2.216e-09 * c **3 - 4.813e-07 * c ** 2  + 3.152e-05 * c - 0.0001162"
+                )
+
+                #CH4
+                em_arr[:, 4] = ne.evaluate(
+                "1.688e-10 * c **3 - 1.155e-07 * c ** 2  + 4.671e-05 * c + 0.005178"
+                )
+                #NMHC
+                em_arr[:, 5] = ne.evaluate(
+                "1.876e-11 * c **3 - 1.283e-08 * c ** 2  + 5.19e-06 * c + 0.0005754"
+                )
+                #Pb
+                # No Pb!
+
+                #SO2
+                em_arr[:, 7] = ne.evaluate(
+                "3.238e-10 * c **3 + 2.633e-09 * c ** 2  - 5.843e-06 * c + 0.001135"
+                )
+                #N2O
+                em_arr[:, 8] = 0.01
+                #NH3
+                em_arr[:, 9] = 0.006
+                #Benzene 
+                em_arr[:, 10] = ne.evaluate(
+                    "1.501e-12 * c **3 - 1.026e-09 * c ** 2  + 4.152e-07 * c + 4.603e-05"
+                )
+
+            if euro_class == 6.3:
+                # EURO 6-d
                 # HC
                 em_arr[:, 0] = ne.evaluate(
                     "1.42e-09 * c ** 3 - 3.905e-07 * c ** 2 + 6.247e-05 * c + 0.004804"
@@ -319,7 +450,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.159e-07 * c ** 3 - 1.891e-05 * c ** 2 + 0.0008328 * c + 0.01852) + (4.056e-08 * c ** 3 - 6.618e-06 * c ** 2 + 0.0002915 * c + 0.006481)"
+                    "(1.159e-07 * c ** 3 - 1.891e-05 * c ** 2 + 0.0008328 * c + 0.01852)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] =  ne.evaluate(
@@ -361,7 +492,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(-2.973e-07 * c ** 3 + 0.00018 * c ** 2 - 0.01601 * c + 1.184) + (-1.486e-08 * c ** 3 + 9e-06 * c ** 2 - 0.0008007 * c + 0.05918)"
+                    "(-2.973e-07 * c ** 3 + 0.00018 * c ** 2 - 0.01601 * c + 1.184)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] =  ne.evaluate(
@@ -403,7 +534,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(-5.15e-08 * c ** 3 + 8.582e-05 * c ** 2 - 0.01024 * c + 0.5778) + (-2.575e-09 * c ** 3 + 4.291e-06 * c ** 2 - 0.0005118 * c + 0.02889)"
+                    "(-5.15e-08 * c ** 3 + 8.582e-05 * c ** 2 - 0.01024 * c + 0.5778)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate(
@@ -444,7 +575,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(4.472e-07 * c ** 3 - 5.03e-05 * c ** 2 - 0.001425 * c + 0.3272) + (2.236e-08 * c ** 3 - 2.515e-06 * c ** 2 - 7.123e-05 * c + 0.01636)"
+                    "(4.472e-07 * c ** 3 - 5.03e-05 * c ** 2 - 0.001425 * c + 0.3272)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate(
@@ -485,7 +616,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.383e-07 * c ** 3 - 1.557e-05 * c ** 2 - 0.0004461 * c + 0.1016) + (6.916e-09 * c ** 3 - 7.783e-07 * c ** 2 - 2.23e-05 * c + 0.005081)"
+                    "(1.383e-07 * c ** 3 - 1.557e-05 * c ** 2 - 0.0004461 * c + 0.1016)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate(
@@ -526,7 +657,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.427e-07 * c ** 3 - 2.47e-05 * c ** 2 + 0.001137 * c + 0.03733) + (7.135e-09 * c ** 3 - 1.235e-06 * c ** 2 + 5.683e-05 * c + 0.001866)"
+                    "(1.427e-07 * c ** 3 - 2.47e-05 * c ** 2 + 0.001137 * c + 0.03733)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate(
@@ -567,7 +698,7 @@ class HotEmissionsModel:
                 )
                 # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(2.053e-08 * c ** 3 - 2.671e-06 * c ** 2 - 0.0002311 * c + 0.04269) + (1.026e-09 * c ** 3 - 1.336e-07 * c ** 2 - 1.156e-05 * c + 0.002134)"
+                    "(2.053e-08 * c ** 3 - 2.671e-06 * c ** 2 - 0.0002311 * c + 0.04269)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate(
@@ -597,46 +728,173 @@ class HotEmissionsModel:
                 em_arr[:, 10] = ne.evaluate(
                     "-6.38e-10 * c ** 3 + 1.259e-07 * c ** 2 - 7.827e-06 * c + 9.119e-05"
                 )
-            if euro_class == 6:
+            if euro_class == 6.0:
+                # EURO 6-ab
                 # HC
                 em_arr[:, 0] = ne.evaluate(
-                    "-6.698e-09 * c ** 3 + 2.661e-06 * c ** 2 - 0.0002239 * c + 0.008068"
+                    "1.861e-08 * c ** 3 - 3.288e-06 * c ** 2 + 0.0001836 * c + 0.001005"
                 )
                 # CO
                 em_arr[:, 1] = ne.evaluate(
-                    "5.385e-07 * c ** 3 - 0.0001104 * c ** 2 + 0.006821 * c + 0.1707"
+                    "5.22e-06 * c ** 3 - 0.001098 * c ** 2 + 0.07276 * c - 1.225"
                 )
-                # NO + NO2
+                # NOx + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(1.379e-07 * c ** 3 - 2.708e-05 * c ** 2 + 0.001678 * c - 0.01762) + (6.894e-09 * c ** 3 - 1.354e-06 * c ** 2 + 8.388e-05 * c - 0.0008809)"
+                    "(3.746e-09 * c ** 3 - 3.01e-07 * c ** 2 - 0.0001707 * c + 0.04678)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate(
-                    "-3.18e-10 * c ** 3 + 2.95e-07 * c ** 2 - 2.911e-05 * c + 0.001359"
+                    "5.402e-10 * c ** 3 + 7.947e-08 * c ** 2 - 2.936e-05 * c + 0.002263"
                 )
                 # CH4
                 em_arr[:, 4] = ne.evaluate(
-                    "-2.679e-09 * c ** 3 + 1.064e-06 * c ** 2 - 8.957e-05 * c + 0.003227"
+                    "7.443e-09 * c ** 3 - 1.315e-06 * c ** 2 + 7.344e-05 * c + 0.0004021"
                 )
                 # NMVOC
                 em_arr[:, 5] = ne.evaluate(
-                    "-4.019e-09 * c ** 3 + 1.597e-06 * c ** 2 - 0.0001344 * c + 0.004841"
+                    "1.116e-08 * c ** 3 - 1.973e-06 * c ** 2 + 0.0001102 * c + 0.0006032"
                 )
                 # Pb
                 em_arr[:, 6] = ne.evaluate(
-                    "-2.062e-11 * c ** 3 + 9.669e-09 * c ** 2 - 1.099e-06 * c + 7.273e-05"
+                    "-2.745e-11 * c ** 3 + 1.268e-08 * c ** 2 - 1.436e-06 * c + 9.009e-05"
                 )
                 # SO2
                 em_arr[:, 7] = ne.evaluate(
-                    "-3.264e-10 * c ** 3 + 1.53e-07 * c ** 2 - 1.74e-05 * c + 0.001151"
+                    "-4.344e-10 * c ** 3 + 2.007e-07 * c ** 2 - 2.273e-05 * c + 0.001426"
                 )
                 # N2O
-                em_arr[:, 8] = 8.5e-4
+                em_arr[:, 8] = 2.5e-4
                 # NH3
                 em_arr[:, 9] = 0.019
                 # Benzene
                 em_arr[:, 10] = ne.evaluate(
-                    "-6.698e-11 * c ** 3 + 2.661e-08 * c ** 2 - 2.239e-06 * c + 8.068e-05"
+                    "1.861e-10 * c ** 3 - 3.288e-08 * c ** 2 + 1.836e-06 * c + 1.005e-05"
+                )
+            if euro_class == 6.1:
+                # EURO 6-c
+                # HC
+                em_arr[:, 0] = ne.evaluate(
+                    "7.335e-09 * c ** 3 - 1.343e-06 * c ** 2 + 8.808e-05 * c - 0.0008577"
+                )
+                # CO
+                em_arr[:, 1] = ne.evaluate(
+                    "1.848e-06 * c ** 3 - 0.0003671 * c ** 2 + 0.02352 * c - 0.2435"
+                )
+                # NOx + NO2
+                em_arr[:, 2] = ne.evaluate(
+                    "(-7.317e-09 * c ** 3 + 2.929e-06 * c ** 2 - 0.0003728 * c + 0.02627)"
+                )
+                # PM <= 2.5 um
+                em_arr[:, 3] = ne.evaluate(
+                    "-3.9e-10 * c ** 3 + 1.517e-07 * c ** 2 - 1.904e-05 * c + 0.001032"
+                )
+                # CH4
+                em_arr[:, 4] = ne.evaluate(
+                    "2.934e-09 * c ** 3 - 5.373e-07 * c ** 2 + 3.523e-05 * c - 0.0003431"
+                )
+                # NMVOC
+                em_arr[:, 5] = ne.evaluate(
+                    "4.401e-09 * c ** 3 - 8.06e-07 * c ** 2 + 5.285e-05 * c - 0.0005146"
+                )
+                # Pb
+                em_arr[:, 6] = ne.evaluate(
+                    "-2.561e-11 * c ** 3 + 1.161e-08 * c ** 2 - 1.309e-06 * c + 8.137e-05"
+                )
+                # SO2
+                em_arr[:, 7] = ne.evaluate(
+                    "-4.053e-10 * c ** 3 + 1.837e-07 * c ** 2 - 2.073e-05 * c + 0.001288"
+                )
+                # N2O
+                em_arr[:, 8] = 2.5e-4
+                # NH3
+                em_arr[:, 9] = 0.019
+                # Benzene
+                em_arr[:, 10] = ne.evaluate(
+                    "7.335e-11 * c ** 3 - 1.343e-08 * c ** 2 + 8.808e-07 * c - 8.577e-06"
+                )
+            if euro_class == 6.2:
+                # EURO 6-d-temp
+                # HC
+                em_arr[:, 0] = ne.evaluate(
+                    "-7.731e-09 * c ** 3 + 2.908e-06 * c ** 2 - 0.0002415 * c + 0.008536"
+                )
+                # CO
+                em_arr[:, 1] = ne.evaluate(
+                    "9.503e-07 * c ** 3 - 0.0001961 * c ** 2 + 0.0125 * c + 0.06203"
+                )
+                # NOx + NO2
+                em_arr[:, 2] = ne.evaluate(
+                    "(1.334e-07 * c ** 3 - 2.541e-05 * c ** 2 + 0.001513 * c - 0.01215)"
+                )
+                # PM <= 2.5 um
+                em_arr[:, 3] = ne.evaluate(
+                    "-9.717e-10 * c ** 3 + 4.452e-07 * c ** 2 - 4.106e-05 * c + 0.001644"
+                )
+                # CH4
+                em_arr[:, 4] = ne.evaluate(
+                    "-3.093e-09 * c ** 3 + 1.163e-06 * c ** 2 - 9.659e-05 * c + 0.003414"
+                )
+                # NMVOC
+                em_arr[:, 5] = ne.evaluate(
+                    "-4.639e-09 * c ** 3 + 1.745e-06 * c ** 2 - 0.0001449 * c + 0.005121"
+                )
+                # Pb
+                em_arr[:, 6] = ne.evaluate(
+                    "-2.405e-11 * c ** 3 + 1.101e-08 * c ** 2 - 1.246e-06 * c + 7.88e-05"
+                )
+                # SO2
+                em_arr[:, 7] = ne.evaluate(
+                    "-3.808e-10 * c ** 3 + 1.743e-07 * c ** 2 - 1.972e-05 * c + 0.001247"
+                )
+                # N2O
+                em_arr[:, 8] = 2.5e-4
+                # NH3
+                em_arr[:, 9] = 0.017
+                # Benzene
+                em_arr[:, 10] = ne.evaluate(
+                    "-7.731e-11 * c ** 3 + 2.908e-08 * c ** 2 - 2.415e-06 * c + 8.536e-05"
+                )
+            if euro_class == 6.3:
+                # EURO 6-d
+                # HC
+                em_arr[:, 0] = ne.evaluate(
+                    "-1.092e-08 * c ** 3 + 3.665e-06 * c ** 2 - 0.0002973 * c + 0.009515"
+                )
+                # CO
+                em_arr[:, 1] = ne.evaluate(
+                    "1.742e-07 * c ** 3 - 3.012e-05 * c ** 2 + 0.001088 * c + 0.2879"
+                )
+                # NOx + NO2
+                em_arr[:, 2] = ne.evaluate(
+                    "(1.437e-07 * c ** 3 - 2.75e-05 * c ** 2 + 0.001649 * c - 0.01736)"
+                )
+                # PM <= 2.5 um
+                em_arr[:, 3] = ne.evaluate(
+                    "-7.457e-10 * c ** 3 + 4.05e-07 * c ** 2 - 3.638e-05 * c + 0.001481"
+                )
+                # CH4
+                em_arr[:, 4] = ne.evaluate(
+                    "-4.369e-09 * c ** 3 + 1.466e-06 * c ** 2 - 0.0001189 * c + 0.003806"
+                )
+                # NMVOC
+                em_arr[:, 5] = ne.evaluate(
+                    "-6.554e-09 * c ** 3 + 2.199e-06 * c ** 2 - 0.0001784 * c + 0.005709"
+                )
+                # Pb
+                em_arr[:, 6] = ne.evaluate(
+                    "-1.843e-11 * c ** 3 + 8.969e-09 * c ** 2 - 1.026e-06 * c + 6.87e-05"
+                )
+                # SO2
+                em_arr[:, 7] = ne.evaluate(
+                    "-2.917e-10 * c ** 3 + 1.42e-07 * c ** 2 - 1.625e-05 * c + 0.001087"
+                )
+                # N2O
+                em_arr[:, 8] = 2.5e-4
+                # NH3
+                em_arr[:, 9] = 0.019
+                # Benzene
+                em_arr[:, 10] = ne.evaluate(
+                    "-1.092e-10 * c ** 3 + 3.665e-08 * c ** 2 - 2.973e-06 * c + 9.515e-05"
                 )
 
         if powertrain_type == "CNG":
@@ -651,7 +909,7 @@ class HotEmissionsModel:
                     )
                 # NO + NO2
                 em_arr[:, 2] =  ne.evaluate(
-                    "(3.802e-07 * c ** 3 - 4.275e-05 * c ** 2 - 0.001211 * c + 0.2782) + (2.37e-08 * c ** 3 - 2.666e-06 * c ** 2 - 7.551e-05 * c + 0.01734)"
+                    "(3.802e-07 * c ** 3 - 4.275e-05 * c ** 2 - 0.001211 * c + 0.2782)"
                 )
 
                 # PM <= 2.5 um
@@ -693,7 +951,7 @@ class HotEmissionsModel:
                     )
                 # NO + NO2
                 em_arr[:, 2] =  ne.evaluate(
-                    "(2.075e-07 * c ** 3 - 2.335e-05 * c ** 2 - 0.0006691 * c + 0.1524) + (1.452e-08 * c ** 3 - 1.634e-06 * c ** 2 - 4.684e-05 * c + 0.01067)"
+                    "(2.075e-07 * c ** 3 - 2.335e-05 * c ** 2 - 0.0006691 * c + 0.1524)"
                 )
 
                 # PM <= 2.5 um
@@ -736,7 +994,7 @@ class HotEmissionsModel:
 
                 # NO + NO2
                 em_arr[:, 2] =  ne.evaluate(
-                    "(1.775e-06 * c ** 3 - 0.0003727 * c ** 2 + 0.02381 * c - 0.3833) + (1.398e-07 * c ** 3 - 2.943e-05 * c ** 2 + 0.001887 * c - 0.03122)"
+                    "(1.775e-06 * c ** 3 - 0.0003727 * c ** 2 + 0.02381 * c - 0.3833)"
                 )
 
                 # PM <= 2.5 um
@@ -778,7 +1036,7 @@ class HotEmissionsModel:
                     )
                 # NO + NO2
                 em_arr[:, 2] =  ne.evaluate(
-                    "(2.835e-07 * c ** 3 - 5.778e-05 * c ** 2 + 0.003404 * c - 0.02752) + (2.238e-08 * c ** 3 - 4.585e-06 * c ** 2 + 0.000276 * c - 0.002851)"
+                    "(2.835e-07 * c ** 3 - 5.778e-05 * c ** 2 + 0.003404 * c - 0.02752)"
                 )
 
                 # PM <= 2.5 um
@@ -820,7 +1078,7 @@ class HotEmissionsModel:
                     )
                 # NO + NO2
                 em_arr[:, 2] = ne.evaluate(
-                    "(2.163e-08 * c ** 3 - 3.758e-06 * c ** 2 + 5.485e-05 * c + 0.02848) + (4.35e-09 * c ** 3 - 7.625e-07 * c ** 2 + 2.251e-05 * c + 0.002413)"
+                    "(2.163e-08 * c ** 3 - 3.758e-06 * c ** 2 + 5.485e-05 * c + 0.02848)"
                 )
                 # PM <= 2.5 um
                 em_arr[:, 3] = ne.evaluate(
